@@ -24,6 +24,7 @@ def fun_control_init(
     data_module=None,
     data_set=None,
     data_set_name=None,
+    db_dict_name=None,
     design=None,
     device=None,
     devices=1,
@@ -49,6 +50,7 @@ def fun_control_init(
     optimizer=None,
     prep_model=None,
     prep_model_name=None,
+    progress_file=None,
     seed=123,
     show_models=False,
     show_progress=True,
@@ -102,6 +104,8 @@ def fun_control_init(
             The data set object. Default is None.
         data_set_name (str):
             The name of the data set. Default is None.
+        db_dict_name (str):
+            The name of the database dictionary. Default is None.
         device (str):
             The device to use for the training. It can be either "cpu", "mps", or "cuda".
         devices (str or int):
@@ -169,6 +173,8 @@ def fun_control_init(
             The preprocessing model object. Used for river. Default is None.
         prep_model_name (str):
             The name of the preprocessing model. Default is None.
+        progress_file (str):
+            The name of the progress file. Default is None.
         seed (int):
             The seed to use for the random number generator. Default is 123.
         sigma (float):
@@ -243,6 +249,7 @@ def fun_control_init(
                 'core_model_name': None,
                 'data': None,
                 'data_dir': './data',
+                'db_dict_name': None,
                 'device': None,
                 'devices': "auto",
                 'enable_progress_bar': False,
@@ -340,6 +347,7 @@ def fun_control_init(
         "data_module": data_module,
         "data_set": data_set,
         "data_set_name": data_set_name,
+        "db_dict_name": db_dict_name,
         "design": design,
         "device": device,
         "devices": devices,
@@ -373,6 +381,7 @@ def fun_control_init(
         "path": None,
         "prep_model": prep_model,
         "prep_model_name": prep_model_name,
+        "progress_file": progress_file,
         "save_model": False,
         "seed": seed,
         "show_batch_interval": 1_000_000,
@@ -396,7 +405,7 @@ def fun_control_init(
         "verbosity": verbosity,
         "weights": weights,
         "weight_coeff": weight_coeff,
-        "weights_entry": weights_entry
+        "weights_entry": weights_entry,
     }
     # lower = X_reshape(lower)
     # fun_control.update({"lower": lower})
